@@ -318,6 +318,7 @@ from plaid.model.payment_initiation_payment_list_request import PaymentInitiatio
 from plaid.model.payment_initiation_payment_list_response import PaymentInitiationPaymentListResponse
 from plaid.model.payment_initiation_payment_reverse_request import PaymentInitiationPaymentReverseRequest
 from plaid.model.payment_initiation_payment_reverse_response import PaymentInitiationPaymentReverseResponse
+from plaid.model.payment_initiation_payment_status import PaymentInitiationPaymentStatus
 from plaid.model.payment_initiation_payment_token_create_request import PaymentInitiationPaymentTokenCreateRequest
 from plaid.model.payment_initiation_payment_token_create_response import PaymentInitiationPaymentTokenCreateResponse
 from plaid.model.payment_initiation_recipient import PaymentInitiationRecipient
@@ -470,9 +471,11 @@ from plaid.model.transfer_event_type import TransferEventType
 from plaid.model.transfer_failure import TransferFailure
 from plaid.model.transfer_get_request import TransferGetRequest
 from plaid.model.transfer_get_response import TransferGetResponse
+from plaid.model.transfer_intent_create import TransferIntentCreate
 from plaid.model.transfer_intent_create_mode import TransferIntentCreateMode
 from plaid.model.transfer_intent_create_request import TransferIntentCreateRequest
 from plaid.model.transfer_intent_create_response import TransferIntentCreateResponse
+from plaid.model.transfer_intent_get import TransferIntentGet
 from plaid.model.transfer_intent_get_failure_reason import TransferIntentGetFailureReason
 from plaid.model.transfer_intent_get_request import TransferIntentGetRequest
 from plaid.model.transfer_intent_get_response import TransferIntentGetResponse
